@@ -20,25 +20,24 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
-
-from collections import namedtuple
-
 import pytest
 
-from ansiblelint.runner import Runner
+from ansiblelint.file_utils import Lintable
 
-PlayFile = namedtuple('PlayFile', ['name', 'content'])
-
-
-FAIL_TASK_1LN = PlayFile('playbook.yml', '''
+FAIL_TASK_1LN = Lintable(
+    'playbook.yml',
+    '''\
 - hosts: all
   tasks:
     - name: one-level nesting
       set_fact:
         var_one: "2*(1+2) is {{ 2 * {{ 1 + 2 }} }}"
-''')
+''',
+)
 
-FAIL_TASK_1LN_M = PlayFile('playbook.yml', '''
+FAIL_TASK_1LN_M = Lintable(
+    'playbook.yml',
+    '''\
 - hosts: all
   tasks:
     - name: one-level multiline nesting
@@ -47,17 +46,23 @@ FAIL_TASK_1LN_M = PlayFile('playbook.yml', '''
           2*(1+2) is {{ 2 *
           {{ 1 + 2 }}
           }}
-''')
+''',
+)
 
-FAIL_TASK_2LN = PlayFile('playbook.yml', '''
+FAIL_TASK_2LN = Lintable(
+    'playbook.yml',
+    '''\
 - hosts: all
   tasks:
     - name: two-level nesting
       set_fact:
         var_two: "2*(1+(3-1)) is {{ 2 * {{ 1 + {{ 3 - 1 }} }} }}"
-''')
+''',
+)
 
-FAIL_TASK_2LN_M = PlayFile('playbook.yml', '''
+FAIL_TASK_2LN_M = Lintable(
+    'playbook.yml',
+    '''\
 - hosts: all
   tasks:
     - name: two-level multiline nesting
@@ -67,17 +72,23 @@ FAIL_TASK_2LN_M = PlayFile('playbook.yml', '''
           {{ 1 +
           {{ 3 - 1 }}
           }} }}
-''')
+''',
+)
 
-FAIL_TASK_W_5LN = PlayFile('playbook.yml', '''
+FAIL_TASK_W_5LN = Lintable(
+    'playbook.yml',
+    '''\
 - hosts: all
   tasks:
     - name: five-level wild nesting
       set_fact:
         var_three_wld: "{{ {{ {{ {{ {{ 234 }} }} }} }} }}"
-''')
+''',
+)
 
-FAIL_TASK_W_5LN_M = PlayFile('playbook.yml', '''
+FAIL_TASK_W_5LN_M = Lintable(
+    'playbook.yml',
+    '''\
 - hosts: all
   tasks:
     - name: five-level wild multiline nesting
@@ -92,17 +103,23 @@ FAIL_TASK_W_5LN_M = PlayFile('playbook.yml', '''
           }}
           }}
           }}
-''')
+''',
+)
 
-SUCCESS_TASK_P = PlayFile('playbook.yml', '''
+SUCCESS_TASK_P = Lintable(
+    'playbook.yml',
+    '''\
 - hosts: all
   tasks:
     - name: non-nested example
       set_fact:
         var_one: "number for 'one' is {{ 2 * 1 }}"
-''')
+''',
+)
 
-SUCCESS_TASK_P_M = PlayFile('playbook.yml', '''
+SUCCESS_TASK_P_M = Lintable(
+    'playbook.yml',
+    '''\
 - hosts: all
   tasks:
     - name: multiline non-nested example
@@ -110,17 +127,23 @@ SUCCESS_TASK_P_M = PlayFile('playbook.yml', '''
         var_one_ml: >
           number for 'one' is {{
           2 * 1 }}
-''')
+''',
+)
 
-SUCCESS_TASK_2P = PlayFile('playbook.yml', '''
+SUCCESS_TASK_2P = Lintable(
+    'playbook.yml',
+    '''\
 - hosts: all
   tasks:
     - name: nesting far from each other
       set_fact:
         var_two: "number for 'two' is {{ 2 * 1 }} and number for 'three' is {{ 4 - 1 }}"
-''')
+''',
+)
 
-SUCCESS_TASK_2P_M = PlayFile('playbook.yml', '''
+SUCCESS_TASK_2P_M = Lintable(
+    'playbook.yml',
+    '''\
 - hosts: all
   tasks:
     - name: multiline nesting far from each other
@@ -129,17 +152,23 @@ SUCCESS_TASK_2P_M = PlayFile('playbook.yml', '''
           number for 'two' is {{ 2 * 1
           }} and number for 'three' is {{
           4 - 1 }}
-''')
+''',
+)
 
-SUCCESS_TASK_C_2P = PlayFile('playbook.yml', '''
+SUCCESS_TASK_C_2P = Lintable(
+    'playbook.yml',
+    '''\
 - hosts: all
   tasks:
     - name: nesting close to each other
       set_fact:
         var_three: "number for 'ten' is {{ 2 - 1 }}{{ 3 - 3 }}"
-''')
+''',
+)
 
-SUCCESS_TASK_C_2P_M = PlayFile('playbook.yml', '''
+SUCCESS_TASK_C_2P_M = Lintable(
+    'playbook.yml',
+    '''\
 - hosts: all
   tasks:
     - name: multiline nesting close to each other
@@ -148,16 +177,19 @@ SUCCESS_TASK_C_2P_M = PlayFile('playbook.yml', '''
           number for 'ten' is {{
           2 - 1
           }}{{ 3 - 3 }}
-''')
+''',
+)
 
-
-@pytest.fixture
-def runner(tmp_path, default_rules_collection):
-    return Runner(
-        default_rules_collection,
-        str(tmp_path / 'playbook.yml'),
-        [], [], [],
-    )
+SUCCESS_TASK_PRINT = Lintable(
+    'playbook.yml',
+    '''\
+- hosts: all
+  tasks:
+    - name: print curly braces
+      debug:
+        msg: docker image inspect my_image --format='{{'{{'}}.Size{{'}}'}}'
+''',
+)
 
 
 @pytest.fixture
@@ -177,28 +209,38 @@ def _playbook_file(tmp_path, request):
         pytest.param([FAIL_TASK_2LN], id='file includes two-level nesting'),
         pytest.param([FAIL_TASK_2LN_M], id='file includes two-level multiline nesting'),
         pytest.param([FAIL_TASK_W_5LN], id='file includes five-level wild nesting'),
-        pytest.param([FAIL_TASK_W_5LN_M], id='file includes five-level wild multiline nesting'),
+        pytest.param(
+            [FAIL_TASK_W_5LN_M], id='file includes five-level wild multiline nesting'
+        ),
     ),
     indirect=['_playbook_file'],
 )
 @pytest.mark.usefixtures('_playbook_file')
 def test_including_wrong_nested_jinja(runner):
     rule_violations = runner.run()
-    assert rule_violations[0].rule.id == '207'
+    assert rule_violations[0].rule.id == 'no-jinja-nesting'
 
 
 @pytest.mark.parametrize(
     '_playbook_file',
     (
         pytest.param([SUCCESS_TASK_P], id='file includes non-nested example'),
-        pytest.param([SUCCESS_TASK_P_M], id='file includes multiline non-nested example'),
+        pytest.param(
+            [SUCCESS_TASK_P_M], id='file includes multiline non-nested example'
+        ),
         pytest.param([SUCCESS_TASK_2P], id='file includes nesting far from each other'),
-        pytest.param([SUCCESS_TASK_2P_M], id='file includes multiline nesting far from each other'),
-        pytest.param([SUCCESS_TASK_C_2P], id='file includes nesting close to each other'),
+        pytest.param(
+            [SUCCESS_TASK_2P_M],
+            id='file includes multiline nesting far from each other',
+        ),
+        pytest.param(
+            [SUCCESS_TASK_C_2P], id='file includes nesting close to each other'
+        ),
         pytest.param(
             [SUCCESS_TASK_C_2P_M],
             id='file includes multiline nesting close to each other',
         ),
+        pytest.param([SUCCESS_TASK_PRINT], id='file includes print curly braces'),
     ),
     indirect=['_playbook_file'],
 )
